Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Msg is a key used to add message strings to label lists. Msg = NewString("message", "a readable message") // Label is a key used to indicate an event adds labels to the context. Label = NewTag("label", "a label context marker") // Start is used for things like traces that have a name. Start = NewString("start", "span start") // Metric is a key used to indicate an event records metrics. End = NewTag("end", "a span end marker") // Metric is a key used to indicate an event records metrics. Detach = NewTag("detach", "a span detach marker") // Err is a key used to add error values to label lists. Err = NewError("error", "an error that occurred") // Metric is a key used to indicate an event records metrics. Metric = NewTag("metric", "a metric event marker") )
Functions ¶
Types ¶
type Error ¶
type Error struct {
// contains filtered or unexported fields
}
Error represents a key
func (*Error) Description ¶
type Float ¶
type Float struct {
// contains filtered or unexported fields
}
Float is a label.Key for floating-point values.
func (*Float) Description ¶
type Int ¶
type Int struct {
// contains filtered or unexported fields
}
Int is a label.Key for signed integers.
func (*Int) Description ¶
type String ¶
type String struct {
// contains filtered or unexported fields
}
String represents a key
func (*String) Description ¶
type Tag ¶
type Tag struct {
// contains filtered or unexported fields
}
Tag represents a key for tagging labels that have no value. These are used when the existence of the label is the entire information it carries, such as marking events to be of a specific kind, or from a specific package.
func (*Tag) Description ¶
type Uint ¶
type Uint struct {
// contains filtered or unexported fields
}
Uint is a label.Key for unsigned integers.
func (*Uint) Description ¶
Click to show internal directories.
Click to hide internal directories.